@@ -1,10 +1,10 @@
 import json
 from typing import Optional
 
-from ai_openchat.aiiohttp import AiohttpSession
-from ai_openchat.base.model import Model
-from ai_openchat.base.session import BaseSession
-from ai_openchat.utils.token import validate_token
+from aiiohttp import AiohttpSession
+from base.model import Model
+from base.session import BaseSession
+from utils.token import validate_token
 
 
 class AsyncOpenAI:
